PayUWealthTechKeys class

Constructors

PayUWealthTechKeys()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

amount → const String
folio → const String
mfAMCCode → const String
mfInvestmentType → const String
mfMemberID → const String
mfPartner → const String
mfUserID → const String
option → const String
plan → const String
receipt → const String
scheme → const String
type → const String